.onLoad: Select the queueing system on package loading
Description
This is done by setting the variable 'qsys' in the package environment
to the object that contains the desired queueing system. We further call
its setup() function if it exists, and set the variable 'qsys_id' to
the scheduler we use
Usage
.onLoad(libname, pkgname)
Arguments
libname
default arg for compatibility
pkgname
default arg for compatibility