Learn R Programming

clustermq (version 0.8.6)

bind_avail: Binds an rzmq to an available port in given range

Description

Binds an rzmq to an available port in given range

Usage

bind_avail(socket, range, iface = "tcp://*", n_tries = 100)

Arguments

socket

An rzmq socket object

range

Numbers to consider (e.g. 6000:8000)

iface

Interface to listen on

n_tries

Number of ports to try in range

Value

The port the socket is bound to