Learn R Programming

clustermq (version 0.8.6)

QSys: Class for basic queuing system functions

Description

Provides the basic functions needed to communicate between machines This should abstract most functions of rZMQ so the scheduler implementations can rely on the higher level functionality

Usage

QSys

Arguments

Format

An object of class R6ClassGenerator of length 24.