powered by
Provides the basic functions needed to communicate between machines This should abstract most functions of rZMQ so the scheduler implementations can rely on the higher level functionality
QSys
An object of class R6ClassGenerator of length 24.
R6ClassGenerator