worker: R worker submitted as cluster job
Description
Do not call this manually, the master will do that
Usage
worker(master, timeout = 600, ..., verbose = TRUE)
Arguments
master
The master address (tcp://ip:port)
timeout
Time until worker shuts down without hearing from master
...
Catch-all to not break older template values (ignored)
verbose
Whether to print debug messages