Creates a pool of workers
workers(n_jobs, data = NULL, reuse = TRUE, template = list(),
log_worker = FALSE, qsys_id = getOption("clustermq.scheduler",
qsys_default))Number of jobs to submit (0 implies local processing)
Set common data (function, constant args, seed)
Whether workers are reusable or get shut down after call
A named list of values to fill in template
Write a log file for each worker
Character string of QSys class to use
An instance of the QSys class